# ANI model parameters 

Please note that ANI2x, and ANI1ccx model parameters have been move to https://github.com/aiqm/ani-model-zoo in an effort to reduce the size of TorchANI for deployment.

These parameters will be automatically downloaded once the Built-in classes are called.
